=========================================
Environmental Science using Symbolic Math
=========================================

.. image:: https://zenodo.org/badge/90965956.svg
        :target: https://zenodo.org/badge/latestdoi/90965956

.. image:: https://img.shields.io/travis/environmentalscience/essm.svg
        :target: https://travis-ci.org/environmentalscience/essm

.. image:: https://img.shields.io/coveralls/environmentalscience/essm.svg
        :target: https://coveralls.io/r/environmentalscience/essm

.. image:: https://img.shields.io/github/tag/environmentalscience/essm.svg
        :target: https://github.com/environmentalscience/essm/releases

.. image:: https://img.shields.io/pypi/dm/essm.svg
        :target: https://pypi.python.org/pypi/essm

.. image:: https://img.shields.io/github/license/environmentalscience/essm.svg
        :target: https://github.com/environmentalscience/essm/blob/master/LICENSE

This package contains helpers to deal with physical variables and units.

The documentation is available on
https://environmentalscience.github.io/essm/

The quick installation for impatient users can be done by running::

    pip install essm
